@@ -24,7 +24,7 @@ def init_logger(filepath, verbosity=1, name=None):
     logger = logging.getLogger(name)
     logger.setLevel(level_dict[verbosity])
     time_str = time.strftime('%Y_%m_%d_%H_%M_%S')
-    filename = '{}\\exp_{}.log'.format(filepath,time_str)
+    filename = '{}/exp_{}.log'.format(filepath,time_str)
 
     fh = logging.FileHandler(filename, "w")
     fh.setFormatter(formatter)
